@@ -5,14 +5,20 @@
 # See License.txt in the project root for license information.
 # --------------------------------------------------------------------
 
-import pkg_resources
 import sys
+
+import pkg_resources
 from eth_account import Account  # noqa: E402
 
-# from tronpytool.compile.solwrap import SolcWrap
+from .compile.service import Service, BackgroundRun
 from .main import Tron  # noqa: E402
-from .providers.simulateplayer import CoreSimulatePlayers
+from .pen.collectfundscn import Collector
+from .pen.contracttest import CoreSimulatePlayers
+from .pen.eventtest import EventTestCase
+from .pen.membertest import MemberNetworkTestCase
+from .providers.gracefulinterrupter import GracefulInterruptHandler
 from .providers.http import HttpProvider  # noqa: E402
+from .compile.basecore import ContractMethod, EventTracker
 
 if sys.version_info < (3, 5):
     raise EnvironmentError("Python 3.5 or above is required")
@@ -24,6 +30,11 @@ __all__ = [
     'HttpProvider',
     'Account',
     'CoreSimulatePlayers',
-    'Tron'
-    #  'SolcWrap'
+    'MemberNetworkTestCase',
+    'Tron',
+    'Collector',
+    'EventTestCase',
+    'Service',
+    'GracefulInterruptHandler',
+    'BackgroundRun'
 ]
