@@ -2,7 +2,7 @@ import json
 import re
 from typing import Union
 
-from eth_account.datastructures import AttributeDict
+from tronpytool.common.datastructures import AttributeDict
 from eth_utils import (
     hexstr_if_str,
     to_hex,
