@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 """Base wrapper class for accessing ethereum smart contracts."""
-
+from datetime import datetime
 from typing import Any, Union, Tuple
 
 from tronpytool import Tron
@@ -19,7 +19,7 @@ class Validator:
 
     def __init__(
             self,
-            web3_or_provider: Tron,
+            web3_or_provider: any,
             contract_address: str,
     ):
         """Initialize the instance."""
@@ -36,6 +36,57 @@ class Validator:
         """
 
 
+class EventTracker:
+
+    def __init__(self, forceStart: any = False, debug: bool = False):
+        self.callback_event_found = None
+        self.debug = debug
+        self.since = 0
+        if isinstance(forceStart, bool):
+            if forceStart is False:
+                self.updateTracker()
+            else:
+                self.since = 0
+        elif isinstance(forceStart, int):
+            self.since = forceStart
+
+    def trackEvent(self, tron: any, event_name: str, address: str) -> list:
+        event_results = tron.get_event_result(
+            event_name=event_name,
+            since_timestamp=self.since,
+            contract_address=address,
+            only_confirmed=False,
+        )
+
+        if self.debug:
+            print(event_results)
+
+        self.updateTracker()
+
+        if len(event_results) > 0:
+            return event_results
+        else:
+            return list()
+
+    def setCallback(self, callback: any) -> "EventTracker":
+        self.callback_event_found = callback
+        return self
+
+    def isCallBackReady(self) -> bool:
+        return self.callback_event_found is not None
+
+    def setTimeSpecial(self, since: int) -> "EventTracker":
+        self.since = since
+        return self
+
+    def setDebug(self, enabled: bool) -> "EventTracker":
+        self.debug = enabled
+        return self
+
+    def updateTracker(self) -> None:
+        self.since = int(datetime.now().timestamp()) * 1000
+
+
 class ContractMethod:
     debug = True
 
@@ -131,15 +182,19 @@ class ContractMethod:
         if ok:
             print("=========================================")
             print("🦓 transaction ID: {}".format(transaction_id))
+
             offline_sign = self._client.sign(r)
             print("=========================================")
-            print("🐝 sign transaction: {}".format(offline_sign))
+            if self.debug:
+                print("🐝 sign transaction: {}".format(offline_sign))
             result = self._client.broadcast(offline_sign)
-            print("=========================================")
-            print("🐳 result transaction: {}".format(result))
+            if self.debug:
+                print("=========================================")
+                print("🐳 result transaction: {}".format(result))
             transaction_info = self._client.get_transaction_info(transaction_id)
-            print("🐚 detail result for transaction: {}".format(transaction_info))
-            print("=========================================")
+            if self.debug:
+                print("🐚 detail result for transaction: {}".format(transaction_info))
+                print("=========================================")
 
         else:
             raise KeyError('Request returns Error - {} msg:{} txt:{}'.format(key, transaction_id,
